@@ -1,10 +1,10 @@
 gcrq <-
 function(formula, tau=c(.1,.25,.5,.75,.9), data, subset, weights, na.action, transf=NULL,
-    y=TRUE, n.boot=0, eps=0.001,  #ho rimosso cv=FALSE, interc=TRUE,
+    y=TRUE, n.boot=0, eps=0.0001,  #ho rimosso cv=FALSE, interc=TRUE,
     display=FALSE, method=c("REML","ML"), df.opt=2, df.nc=FALSE,
     lambda0=.1, h=0.8, lambda.max=1000, tol=0.01, it.max=15, single.lambda=TRUE, 
     foldid=NULL, nfolds=10, lambda.ridge=0, adjX.constr=TRUE, #sgn.constr=NULL, ,
-    contrasts=NULL, sparse=FALSE){
+    contrasts=NULL, sparse=FALSE, nc.fit=FALSE,...){
 #df.nc: se TRUE, i df calcolati tengono conto dei vincoli noncross (ignorato se la stima e' di una singolo tau)
 #single.lambda: if TRUE (and multiple quantile curves are being estimated) a common spar across the tau values is computed
 #sett 19: aggiunto df.opt=4 (tutto approx quadratica..)
@@ -224,13 +224,14 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
       #fitter<- if(length(tau)>1) get("arq.fitMulti") else get("arq.fit")
       #fit<-fitter(y=Y,X=X,tau=tau,g=g,beta0=b.start,control=control)
       cv<-FALSE #NOn so se serve.. l'ho preso dalla f. del pacchetto..
-      fit <-ncross.rq.fitX(y=Y, X=X, taus=tau, eps=eps, adjX.constr=adjX.constr) #X gi? include l'intercetta
+      fit <-ncross.rq.fitX(y=Y, X=X, taus=tau, eps=eps, adjX.constr=adjX.constr, sparse=sparse, nc.fit=nc.fit, ...) #X gi? include l'intercetta
       if(n.boot>0){
         coef.boot<-array(NA, dim=c(nrow(as.matrix(fit$coef)), length(tau), n.boot))
         id.NA<-NULL
         for(i in 1:n.boot) {
           id<-sample(1:n, size=n, replace=TRUE)
-          .o.b<-try(ncross.rq.fitX(y=Y[id], X=X[id,,drop=FALSE], taus=tau, eps=eps, adjX.constr=adjX.constr), silent=TRUE)
+          .o.b<-try(ncross.rq.fitX(y=Y[id], X=X[id,,drop=FALSE], taus=tau, eps=eps, adjX.constr=adjX.constr, 
+                                   sparse=sparse, nc.fit=nc.fit, ...), silent=TRUE)
           #if(class(.o.b)!="try-error") 
           if(!inherits(.o.b,"try-error"))  coef.boot[,,i]<-.o.b$coef else id.NA[length(id.NA)+1]<-i
         } #end i=1,..,n.boot
@@ -245,7 +246,7 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
         DF.all<-cbind(fit$DF.NEG[,ncol(fit$DF.NEG):1,drop=FALSE], 0, fit$DF.POS)
         fit$edf.all <- fit$edf.all - DF.all
       }
-      fit$edf.j<- matrix(apply(fit$edf.all, 2,sum), nrow=1)
+      fit$edf.j<- matrix(apply(fit$edf.all, 2, sum), nrow=1)
       
       #nuovo maggio 2021.. salva cio' che serve per disegnare i termini lineari
       X<- X[,-match("(Intercept)", colnames(X),0),drop=FALSE]
@@ -268,6 +269,21 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
       #===========================================================================
       drop.id<-lambda<-S<-B<-BB<-nomiCoefPEN<-nomiVariabPEN<-NULL
       l<-lapply(testo.ps,function(xx)with(mf,eval(parse(text=xx),envir=data)))
+      nomiBy<-unlist(sapply(l,function(xx)attr(xx,"nomeBy")))
+      
+      #browser()
+      
+      isLasso <- sapply(l, function(.x) is.matrix(.x) & ncol(.x)>=2) & sapply(nomiBy, function(.x) (.x=="NULL"))
+      
+      if(any(isLasso)){
+        idLasso <- which(isLasso)
+        id1<-idLasso
+        id2<-(1:length(l))[-idLasso]
+        l<-l[c(id1, id2 )]
+        id.ps<- id.ps[c(id1, id2 )]
+        isLasso<-isLasso[c(id1,id2)]
+      }
+      
       vDeg<-sapply(l,function(xx)attr(xx,"deg"))
       vNdx<-sapply(l,function(xx){if(is.null(attr(xx,"ndx"))) round(min(9,n/4)) else attr(xx,"ndx")})
       vMonot<-sapply(l,function(xx)attr(xx,"monot"))
@@ -278,7 +294,6 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
       var.pen<-unlist(sapply(l,function(xx)attr(xx,"var.pen"))) 
       K<- sapply(l,function(xx)attr(xx,"K"))
       ridgeList<-unlist(sapply(l,function(xx)attr(xx,"ridge"))) #TRUE se la variabile e' una matrice o un fattore
-      nomiBy<-unlist(sapply(l,function(xx)attr(xx,"nomeBy")))
       levelsBy<-lapply(l,function(xx)attr(xx,"levelsBy"))
       dimSmooth<-unlist(sapply(l,function(xx)attr(xx,"dimSmooth")))
       decomList<-unlist(sapply(l,function(xx)attr(xx,"decom")))
@@ -292,11 +307,12 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
 		  adList<- unlist(sapply(l,function(xx)attr(xx,"adapt")))
 		  scList<- unlist(sapply(l,function(xx)attr(xx,"sc")))
 		  
-		  #controlla se ci soo vincoli monot e concav con constr.fit=FALSE e base centrata
+		  #controlla se ci sono vincoli monot e concav con constr.fit=FALSE e base centrata
 		  #vMonot, vConc, constr.fitList,dropcList,centerList
 		  
-		  #browser()
-		  if(any(centerList & !dropcList)) stop(paste("center=TRUE and dropc=FALSE incompatible for the smooth term #: ", which(centerList & !dropcList)))
+		 # browser()
+		  if(any(centerList & !dropcList)) stop(paste(
+		      "center=TRUE and dropc=FALSE incompatible for the smooth term #: ", which(centerList & !dropcList)))
 		  #per il msg di sotto, devi guardare bene... se ci sono VC terms?
 		  #if(any(!dropcList) && "(Intercept)"%in%colnames(X)) stop() 
 		  
@@ -586,9 +602,11 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
     }
     X<- X[,-grep( "ps[(]" , colnames(X)), drop=FALSE]
     
-   if(sparse && ncol(X)>0) {
+   #browser()
+    
+    if(sparse && ncol(X)>0) {
      X<-X[,-(1:ncol(X)),drop=FALSE]
-     warning("removing linear terms (including the intercept)' not allowed with 'sparse=TRUE' ")
+     warning("removing linear terms (including the intercept); not allowed with 'sparse=TRUE' ")
    }
     
     BBlin<-vector("list", ncol(X[,setdiff(colnames(X),"(Intercept)"),drop=FALSE]))
@@ -648,6 +666,7 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
     
     
     # fitter<- if(sparse) get("ncross.rq.fitXBsparse", mode="function") else get("ncross.rq.fitXB", mode="function") 
+    #browser()
     
     if(any(lambda<0)){
         sigma2uValues<-matrix(,it.max,length(B))
@@ -696,12 +715,14 @@ bspline <- function(x, ndx, xlr = NULL, knots=NULL, deg = 3, deriv = 0, outer.ok
                                                    Bconstr=BB, df.option=df.option, df.nc=df.nc, adjX.constr=adjX.constr, myeps=myepsV[j], it.j=10,
                                                    adList=adList))
           } else {
+            #browser()
+            
             fit <-suppressWarnings(ncross.rq.fitXB(y=Y, B=B, X=X, taus=tau, monotone=vMonot, concave=vConc, ndx=vNdx,
                     lambda=expand.lambda, deg=vDeg, dif=vDiff, var.pen=var.pen, eps=eps, penMatrix=penMatrixList,
                     lambda.ridge=lambda.ridge, dropcList=dropcList, decomList=decomList, vcList=vcList, dropvcList=dropvcList,
                     centerList=centerList, colmeansB=colMeansB.list, ridgeList=ridgeList, ps.matrix.list=ps.matrix.list,
                     Bconstr=BB, df.option=df.option, df.nc=df.nc, adjX.constr=adjX.constr, myeps=myepsV[j], it.j=10,
-                    adList=adList))
+                    adList=adList, lassoList=isLasso))
                   #NB colMeansBorig.list ha un valore in meno per VC terms!
           }
 
