@@ -4,9 +4,9 @@ ncross.rq.fitXB <-
            ndx=10, deg=3, dif=3, lambda=0, eps=.0001, var.pen=NULL, penMatrix=NULL,
            lambda.ridge=0,  dropcList=FALSE, decomList=FALSE, vcList=FALSE, dropvcList=FALSE, centerList=FALSE, 
            ridgeList=FALSE, ps.matrix.list=FALSE, colmeansB=NULL, Bconstr=NULL, adjX.constr=TRUE, 
-           adList=FALSE, it.j=10, myeps=NULL, ...){
+           adList=FALSE, it.j=10, myeps=NULL, nc=TRUE, lassoList=FALSE,...){
     #usare spam??
-
+    #nc: if TRUE, the nc constraints are set
     plott=0 #prima era un argomento
     adj.middle=FALSE
     err.rho=TRUE #prima era un argomento
@@ -228,7 +228,55 @@ ncross.rq.fitXB <-
       r
     }
     #-------------------------------------
-    
+    perm<-function (n=2, r, v = c(0,1)) {#gtools:permutation
+      v <- unique(sort(v))
+      v0 <- vector(mode(v), 0)
+      sub <- function(n, r, v) {
+        if (r == 1) 
+          matrix(v, n, 1)
+        else if (n == 1) 
+          matrix(v, 1, r)
+        else {
+          inner <- Recall(n, r - 1, v)
+          cbind(rep(v, rep(nrow(inner), n)), matrix(t(inner), 
+                                                    ncol = ncol(inner), nrow = nrow(inner) * n, 
+                                                    byrow = TRUE))
+        }
+      }
+      sub(n, r, v[1:n])
+    }
+    #--------------------------------------------------------
+    build.RR<-function(pLin, id.interc, pSmooth, all.max, colmeansB){
+      #build the constraint matrix
+      #pLin: no. of linear terms (*including* the intercept)
+      #pSmooth: number of basis functions (for all smooths)
+      #all.max: vector of max values of linear covariates (including the 1st value for the intercept if it is in the model)
+      #colmeansB: lista di medie delle basi
+      #browser()
+      #
+      p<-pLin-id.interc #linear covariates
+      if(p<=0) {
+        RR<- if(id.interc>0) rbind(c(1,-unlist(colmeansB)), cbind(0,diag(pSmooth))) else diag(pSmooth) 
+      } else {
+        a<-perm(2, p, c(0,1))
+        a<-a[order(rowSums(a)),,drop=FALSE]
+        if(id.interc>0){
+          a<- a * matrix(all.max[-1], nrow=nrow(a), ncol=p, byrow = TRUE)
+          RR<-cbind(1,a)
+        } else {
+          a<-a[-1,]
+          RR<-a * matrix(all.max, nrow=nrow(a), ncol=p, byrow = TRUE)
+        }
+
+        if(pSmooth>0) {
+          RR<-blockdiag(RR, diag(pSmooth))
+          #RR[1:nrow(a), -(1:pLin)]<- -unlist(colmeansB)
+          RR[1:nrow(a), -(1:pLin)]<- matrix(rep(-unlist(colmeansB),nrow(a)), nrow=nrow(a), byrow = TRUE)
+        }
+      }
+      RR
+    }
+    #--------------------------------------------------------
     taus<-sort(taus)
     n<-length(y)
 
@@ -277,13 +325,18 @@ ncross.rq.fitXB <-
     } else {
       pLin <- 0
       id.interc <- 0
-      }
+    }
+    
+    if(any(monotone!=0 | concave!=0)) nc<-TRUE
+    rq.fit.fnb.mia <- function(x,y,tau,R,r) rq.fit.fnb(x,y,tau)
+    rqFit<-if(nc) get("rq.fit.fnc", mode="function") else get("rq.fit.fnb.mia", mode="function")
+    
     
     #browser()
     #attenzione. Qua se la matrice B comprende variabili da selezionare allora devi comunque consideraarle variabili lineari 
     #e quindi modificare i vincoli..
       
-    if((pLin - id.interc)>0){ #se ci sono variabili lineari (oltre all'eventuale intercetta)
+    if((pLin - id.interc)>0){ #se ci sono variabili lineari (oltre all'eventuale intercetta e oltre termini lasso)
       if(adjX.constr){        
         colnamesX <- colnames(X)
         if(id.interc>0){ #se c'e' intercetta
@@ -304,6 +357,7 @@ ncross.rq.fitXB <-
       }
     } else {
       minX<-NULL
+      all.max<-NULL
       }
 
     if(pLin!=(p-pSmooth)) stop("errore") #pSmooth=p1 #n. termini lineari
@@ -345,6 +399,7 @@ ncross.rq.fitXB <-
       }
     }
     #H <-length(B) #no. of smooth terms
+    
     #browser()
     
     #B <-matrix(unlist(B), n, pSmooth) #matrix(unlist(B), nrow=3,byrow = FALSE)
@@ -432,7 +487,7 @@ ncross.rq.fitXB <-
     
     #browser()
     
-    if(it.j<=2){
+    if(it.j<=2){ #non ricordo (01/10/24  a cosa serva..)
       #o<-rq.fit.fnb(y=y, x=XB, tau=taus) #restituisce solo coef p x ntau
       #colnames(o$coefficients)<- paste(taus)
       #o$fitted.values <- XB.orig%*%o$coefficients
@@ -554,62 +609,83 @@ ncross.rq.fitXB <-
       idsmoothInter <- setdiff(unlist(id.coef.spline),id.coef.spline$Xlin)
       
       #===========================================================================
-
+      #browser()
+      
+      if(any(lassoList)){ #
+        idLasso<- which(lassoList)
+        pLinLasso<-sum(sapply(colmeansB[idLasso],length))
+        RR<-build.RR(pLin+pLinLasso, id.interc, pSmooth-pLinLasso, 
+                    c(all.max, unlist(all.maxB[idLasso])), colmeansB[-idLasso])
+      } else {
+        RR <- build.RR(pLin, id.interc, pSmooth, all.max, colmeansB)
+        
+      }
+      nv0<-nrow(RR)
+      #browser()
+      
       #===========================================================================
       if(n.pos.taus>0){
         rho.pos.tau <-df.pos.tau <- vector(length=n.pos.taus)
         COEF.POS<-matrix(,ncol(XB),n.pos.taus)
         colnames(COEF.POS)<-paste(pos.taus)
         b.start<-o.start$coef
+        
+        #rr<- if(id.interc>0) c(sum(o.start$coefficients*RR[1,]), o.start$coefficients[-1]) else o.start$coefficients
+        #rr<-rr+eps
+        
+        rr<-RR%*%b.start + eps
+        
         if(any(monotone!=0 | concave!=0)){
-          RR<-rbind(Ident, R.monot)
-          rr<-c(b.start + eps, r.monot)
-        } else {
-          RR<- Ident
-          rr<- b.start + eps
+          RR<-rbind(RR, R.monot)
+          rr<-c(rr, r.monot)
         }
+        
+        
+        # if(any(monotone!=0 | concave!=0)){
+        #   RR<-rbind(Ident, R.monot)
+        #   rr<-c(b.start + eps, r.monot)
+        # } else {
+        #   RR<- Ident
+        #   rr<- b.start + eps
+        # }
+        
         #DF per NONcrossing
         DF.POS <- matrix(,nrow(RR),n.pos.taus)
         colnames(DF.POS) <- paste(pos.taus)
         
-        if(id.interc.Constr){ #se c'e' interc con smooth (incompleti, cioe' chiamati con dropc=FALSE)
-          RR[1, idsmoothInter] <- valueNcrosInterc #valueNcrosInterc sono le "-colmeansB"
-          rr[1] <- b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter]) #b.start[1]+sum((-all.means.B)*b.start[id.smooth])
-        }
-        #n.righe = p
-        #id.Matr: p x "n. di termini lineari + n.smooth". Se non ci sono termini lineari la 1st colonna e' una colonna di FALSE..
-
-        if((pLin - id.interc)>0){ #se ci sono variabili lineari (oltre all'eventuale intercetta)
-#          colnamesX <- colnames(X)
-#          all.max<-apply(X,2,max)
-          if(id.interc>0){ #se c'e' intercetta
-            RR[c(FALSE,id.Matr[-1,1]),1]<-1 #aggiungi gli 1 nella prima *colonna* in corrispondenza dei termini lineari
-            rr[2:pLin] <- b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps
-            
-          } else {
-            rr[1:pLin] <- b.start[1:pLin]*all.max[1:pLin] + eps
-#            minX <- apply(X[,-1, drop=FALSE] ,2, min)
-#            names(minX)<-colnames(X)
-#            X <- apply(X, 2, function(.x) .x- min(.x))
-          }
-          diag(RR)[1:pLin]<- all.max  #aggiungi i max sulla diag principale
- #         colnames(X) <- colnamesX
-        }
         
-        #browser()
+        #
         
-        for(j in 1:H) {
-          if(ps.matrix.list[j]) {
-            RR[id.Matr[,j+1], 1] <- 1
-            diag(RR)[id.Matr[,j+1]]<-all.maxB[[j]]
-            
-            if(id.interc>0) {
-              rr[id.Matr[,j+1]] <- b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
-            } else {
-              rr[id.Matr[,j+1]] <- b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
-            }
-          }
-        }
+        # if(id.interc.Constr){ #se c'e' interc con smooth (cioe' chiamati con dropc=FALSE)
+        #   RR[1, idsmoothInter] <- valueNcrosInterc #valueNcrosInterc sono le "-colmeansB"
+        #   rr[1] <- b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter]) #b.start[1]+sum((-all.means.B)*b.start[id.smooth])
+        # }
+        # #n.righe = p
+        # #id.Matr: p x "n. di termini lineari + n.smooth". Se non ci sono termini lineari la 1st colonna e' una colonna di FALSE..
+        # 
+        # if((pLin - id.interc)>0){ #se ci sono variabili lineari (oltre all'eventuale intercetta)
+        #   if(id.interc>0){#se c'e' intercetta
+        #     RR[c(FALSE,id.Matr[-1,1]),1]<-1 #aggiungi gli 1 nella prima *colonna* in corrispondenza dei termini lineari
+        #     rr[2:pLin] <- b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps
+        #     } else {
+        #     rr[1:pLin] <- b.start[1:pLin]*all.max[1:pLin] + eps
+        #   }
+        #   diag(RR)[1:pLin]<- all.max  #aggiungi i max sulla diag principale
+        # }
+        # 
+        # 
+        # for(j in 1:H) {
+        #   if(ps.matrix.list[j]) {
+        #     RR[id.Matr[,j+1], 1] <- 1
+        #     diag(RR)[id.Matr[,j+1]]<-all.maxB[[j]]
+        #     
+        #     if(id.interc>0) {
+        #       rr[id.Matr[,j+1]] <- b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
+        #     } else {
+        #       rr[id.Matr[,j+1]] <- b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
+        #     }
+        #   }
+        # }
         
         FIT.POS<-RES.POS<-matrix(,n,n.pos.taus)
         sigma2u.pos.tau<-matrix(,H,n.pos.taus)
@@ -626,9 +702,11 @@ ncross.rq.fitXB <-
             if(lambda.ridge>0) XB<-rbind(XB, lambda.ridge*diag(ncol(XB))) #a small ridge penalty
           }
           
+          
           #browser()
           
-          o<-rq.fit(x=XB, y=y, tau=pos.taus[i], method="fnc", R=RR, r=rr)
+          o<-rqFit(x=XB, y=y, tau=pos.taus[i], R=RR, r=rr)
+          #o<-rq.fit(x=XB, y=y, tau=pos.taus[i], method="fnc", R=RR, r=rr)
           #o<-rq.fit.fnc(x=XB, y=y, tau=pos.taus[i], method="fnc", R=RR, r=rr, eps=myeps)
           if(!all(is.finite(o$coefficients))) warning(paste("Some NA estimate in the quantile tau =", pos.taus[i], sep="" ))
           
@@ -637,7 +715,7 @@ ncross.rq.fitXB <-
           #browser()
           
           #estrai fitted e residuals
-          FIT.POS[,i]<-o$fitted.values[1:n]
+          FIT.POS[,i]<- y[1:n] - o$residuals[1:n] #o$fitted.values[1:n]
           RES.POS[,i]<-o$residuals[1:n]
           #estrai la f. obiettivo
           #df.pos.tau[i] <- sum(abs(o$residuals[1:n])<=.000001)
@@ -655,30 +733,35 @@ ncross.rq.fitXB <-
           #vedi come considerare l'epsilon.. Inoltre la matrice RR include anche monot/conc
           #in particolare i primi RR[1:p,]b.start rr[1:p] sono per il NONCROSSING
           DF.POS[,i] <- 1*(drop(RR%*%b.start-rr)<=1e-8)
-
-          rr<- if(any(monotone!=0 | concave!=0)) c(b.start+eps, r.monot) else b.start + eps
           
-          if(id.interc.Constr){ #se ci sono smooth con interc
-            #  rr[1] <- sum(valueNcrosInterc * b.start[idsmoothInter]) #b.start[1]-sum(all.means.B*b.start[id.smooth])
-            rr[1] <- b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter])
-          }
-          if((pLin - id.interc)>0) { #se ci sono termini lineari oltre l'intercetta
-            if(id.interc>0){
-              rr[2:pLin] <- b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps
-            } else {
-              rr[1:pLin] <- b.start[1:pLin]*all.max[1:pLin] + eps
-            }
-          }
+          #if(i==2) browser()
+          rr[1:nv0]<-(RR[1:nv0,]%*%b.start) + eps
+          #if(any(monotone!=0 | concave!=0)) rr<-c(rr, r.monot)
 
-          for(j in 1:H) {
-            if(ps.matrix.list[j]) {
-              if(id.interc>0) {
-                rr[id.Matr[,j+1]] <- b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
-              } else {
-                rr[id.Matr[,j+1]] <- b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
-              }
-            }
-          }
+
+          # rr<- if(any(monotone!=0 | concave!=0)) c(b.start+eps, r.monot) else b.start + eps
+          # 
+          # if(id.interc.Constr){ #se ci sono smooth con interc
+          #   #  rr[1] <- sum(valueNcrosInterc * b.start[idsmoothInter]) #b.start[1]-sum(all.means.B*b.start[id.smooth])
+          #   rr[1] <- b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter])
+          # }
+          # if((pLin - id.interc)>0) { #se ci sono termini lineari oltre l'intercetta
+          #   if(id.interc>0){
+          #     rr[2:pLin] <- b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps
+          #   } else {
+          #     rr[1:pLin] <- b.start[1:pLin]*all.max[1:pLin] + eps
+          #   }
+          # }
+          # 
+          # for(j in 1:H) {
+          #   if(ps.matrix.list[j]) {
+          #     if(id.interc>0) {
+          #       rr[id.Matr[,j+1]] <- b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
+          #     } else {
+          #       rr[id.Matr[,j+1]] <- b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps
+          #     }
+          #   }
+          # }
 
           o$n<-n
           #--------calcolo edf
@@ -706,55 +789,66 @@ ncross.rq.fitXB <-
         colnames(COEF.NEG)<-paste(neg.taus)
         b.start<-o.start$coef
         neg.taus<-sort(neg.taus,TRUE)
+        
+        RR<- -RR[1:nv0,]
+        rr<-RR%*%b.start + eps
+        
         if(any(monotone!=0 | concave!=0)){
-          Ident<-diag(p)
-          RR<-rbind(-Ident, R.monot)
-          rr <-c(-b.start - eps, r.monot)
-        } else {
-          RR<- -Ident
-          rr<- -b.start - eps
+          RR<-rbind(RR, R.monot)
+          rr<-c(rr, r.monot)
         }
+        
+        
+        
+        # if(any(monotone!=0 | concave!=0)){
+        #   Ident<-diag(p)
+        #   RR<-rbind(-Ident, R.monot)
+        #   rr <-c(-b.start - eps, r.monot)
+        # } else {
+        #   RR<- -Ident
+        #   rr<- -b.start - eps
+        # }
         #DF per NONcrossing
         DF.NEG<- matrix(,nrow(RR),n.neg.taus)
         colnames(DF.NEG)<-paste(neg.taus)
         
-        if(id.interc.Constr){ #se ci sono smooth con interc
-          RR[1, idsmoothInter] <- -valueNcrosInterc #valueNcrosInterc sono le "-colmeansB"
-          rr[1] <- -(b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter])) #b.start[1]+sum((-all.means.B)*b.start[id.smooth])
-        }
-        
-        if((pLin - id.interc)>0){ #se ci sono variabili lineari (oltre all'eventuale intercetta)
-          #colnamesX <- colnames(X)
-          #all.max<-apply(X,2,max)
-          if(id.interc>0){ #se c'e' intercetta
-            RR[c(FALSE,id.Matr[-1,1]),1]<- -1 #aggiungi i -1 nella prima *colonna* in corrispondenza dei termini lineari
-            rr[2:pLin] <- -(b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps)
-#            minX <- apply(X[,-1, drop=FALSE] ,2, min)
-#            names(minX)<-colnames(X)[-1]
-#            X <- cbind(X[,1], apply(X[,-1, drop=FALSE], 2, function(.x) .x- min(.x)))
-          } else {
-            rr[1:pLin] <- -(b.start[1:pLin]*all.max[1:pLin] + eps)
-#            minX <- apply(X[,-1, drop=FALSE] ,2, min)
-#            names(minX)<-colnames(X)
-#            X <- apply(X, 2, function(.x) .x- min(.x))
-          }
-          diag(RR)[1:pLin]<- -all.max  #aggiungi i max sulla diag principale
-#          colnames(X) <- colnamesX
-        }
-        
-        
-        for(j in 1:H) {
-          if(ps.matrix.list[j]) {
-            RR[id.Matr[,j+1], 1] <- -1
-            diag(RR)[id.Matr[,j+1]]<- -all.maxB[[j]]
-            
-            if(id.interc>0) {
-              rr[id.Matr[,j+1]] <- -(b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
-            } else {
-              rr[id.Matr[,j+1]] <- -(b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
-            }
-          }
-        }
+#         if(id.interc.Constr){ #se ci sono smooth con interc
+#           RR[1, idsmoothInter] <- -valueNcrosInterc #valueNcrosInterc sono le "-colmeansB"
+#           rr[1] <- -(b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter])) #b.start[1]+sum((-all.means.B)*b.start[id.smooth])
+#         }
+#         
+#         if((pLin - id.interc)>0){ #se ci sono variabili lineari (oltre all'eventuale intercetta)
+#           #colnamesX <- colnames(X)
+#           #all.max<-apply(X,2,max)
+#           if(id.interc>0){ #se c'e' intercetta
+#             RR[c(FALSE,id.Matr[-1,1]),1]<- -1 #aggiungi i -1 nella prima *colonna* in corrispondenza dei termini lineari
+#             rr[2:pLin] <- -(b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps)
+# #            minX <- apply(X[,-1, drop=FALSE] ,2, min)
+# #            names(minX)<-colnames(X)[-1]
+# #            X <- cbind(X[,1], apply(X[,-1, drop=FALSE], 2, function(.x) .x- min(.x)))
+#           } else {
+#             rr[1:pLin] <- -(b.start[1:pLin]*all.max[1:pLin] + eps)
+# #            minX <- apply(X[,-1, drop=FALSE] ,2, min)
+# #            names(minX)<-colnames(X)
+# #            X <- apply(X, 2, function(.x) .x- min(.x))
+#           }
+#           diag(RR)[1:pLin]<- -all.max  #aggiungi i max sulla diag principale
+# #          colnames(X) <- colnamesX
+#         }
+#         
+#         
+#         for(j in 1:H) {
+#           if(ps.matrix.list[j]) {
+#             RR[id.Matr[,j+1], 1] <- -1
+#             diag(RR)[id.Matr[,j+1]]<- -all.maxB[[j]]
+#             
+#             if(id.interc>0) {
+#               rr[id.Matr[,j+1]] <- -(b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
+#             } else {
+#               rr[id.Matr[,j+1]] <- -(b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
+#             }
+#           }
+#         }
         
 
         FIT.NEG<-RES.NEG<-matrix(,n,n.neg.taus)
@@ -777,8 +871,8 @@ ncross.rq.fitXB <-
           }
           
           #browser()
-          
-          o<-rq.fit.fnc(x=XB,y=y,tau=neg.taus[i],R=RR,r=rr)
+          o<-rqFit(x=XB, y=y, tau=neg.taus[i], R=RR, r=rr)
+          #o<-rq.fit.fnc(x=XB,y=y,tau=neg.taus[i],R=RR,r=rr)
           #o<-rq.fit.fnc(x=XB,y=y,tau=neg.taus[i], R=RR, r=rr, eps=myeps)
           ##########==============================================================
           
@@ -803,31 +897,32 @@ ncross.rq.fitXB <-
           b.start<-o$coef
           COEF.NEG[,i]<-b.start
           DF.NEG[,i] <- 1*(drop(RR%*%b.start-rr)<=1e-8)
-          # rr<- if(monotone!=0) c(-b.start+eps, rep(0,p1-1) ) else -b.start+eps
-          rr<- if(any(monotone!=0 | concave!=0)) c(-b.start+eps, r.monot) else -b.start + eps
           
-          if(id.interc.Constr){ #se ci sono smooth con interc
-            #  rr[1] <- sum(valueNcrosInterc * b.start[idsmoothInter]) #b.start[1]-sum(all.means.B*b.start[id.smooth])
-            rr[1] <- -(b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter]))
-          }
+          rr[1:nv0]<-RR[1:nv0,]%*%b.start + eps
+          #rr<- if(any(monotone!=0 | concave!=0)) c(-b.start+eps, r.monot) else -b.start + eps
           
-          if((pLin - id.interc)>0) { #se ci sono termini lineari oltre l'intercetta
-            if(id.interc>0){
-              rr[2:pLin] <- -(b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps)
-            } else {
-              rr[1:pLin] <- -(b.start[1:pLin]*all.max[1:pLin] + eps)
-            }
-          }
-          
-          for(j in 1:H) {
-            if(ps.matrix.list[j]) {
-              if(id.interc>0) {
-                rr[id.Matr[,j+1]] <- -(b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
-              } else {
-                rr[id.Matr[,j+1]] <- -(b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
-              }
-            }
-          }
+          # if(id.interc.Constr){ #se ci sono smooth con interc
+          #   #  rr[1] <- sum(valueNcrosInterc * b.start[idsmoothInter]) #b.start[1]-sum(all.means.B*b.start[id.smooth])
+          #   rr[1] <- -(b.start[1] + sum(valueNcrosInterc * b.start[idsmoothInter]))
+          # }
+          # 
+          # if((pLin - id.interc)>0) { #se ci sono termini lineari oltre l'intercetta
+          #   if(id.interc>0){
+          #     rr[2:pLin] <- -(b.start[1] + b.start[2:pLin]*all.max[2:pLin] + eps)
+          #   } else {
+          #     rr[1:pLin] <- -(b.start[1:pLin]*all.max[1:pLin] + eps)
+          #   }
+          # }
+          # 
+          # for(j in 1:H) {
+          #   if(ps.matrix.list[j]) {
+          #     if(id.interc>0) {
+          #       rr[id.Matr[,j+1]] <- -(b.start[1] + b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
+          #     } else {
+          #       rr[id.Matr[,j+1]] <- -(b.start[id.Matr[,j+1]]*all.maxB[[j]] + eps)
+          #     }
+          #   }
+          # }
           
           o$n<-n
           #--------calcolo edf
