@@ -4,7 +4,7 @@ ncross.rq.fitXBsparse <-
            ndx=10, deg=3, dif=3, lambda=0, eps=.0001, var.pen=NULL, penMatrix=NULL,
            lambda.ridge=0,  dropcList=FALSE, decomList=FALSE, vcList=FALSE, dropvcList=FALSE, centerList=FALSE, 
            ridgeList=FALSE, ps.matrix.list=FALSE, colmeansB=NULL, Bconstr=NULL, adjX.constr=TRUE, 
-           adList=FALSE, it.j=10, myeps=NULL, ...){
+           adList=FALSE, it.j=10, myeps=NULL, nc=TRUE, ...){
     #usare spam??
 
     plott=0 #prima era un argomento
@@ -285,8 +285,11 @@ ncross.rq.fitXBsparse <-
     # } else {
       minX<-NULL
       #}
-
-    if(pLin!=(p-pSmooth)) stop("errore") #pSmooth=p1 #n. termini lineari
+      if(any(monotone!=0 | concave!=0)) nc<-TRUE
+      rq.fit.sfn.mia <- function(x,y,tau,R,r) rq.fit.sfn(x,y,tau)
+      rqFit<-if(nc) get("rq.fit.sfnc", mode="function") else get("rq.fit.sfn.mia", mode="function")
+      
+      if(pLin!=(p-pSmooth)) stop("errore") #pSmooth=p1 #n. termini lineari
 
     all.edf<-matrix(NA,p,length(taus))
     group.edf<- matrix(NA, H+(pLin>0),length(taus))
@@ -415,8 +418,13 @@ ncross.rq.fitXBsparse <-
     #XBm<- as.matrix(XB) #serve per edf.rqXB()
     y <- c(y, rep(0,nrow(XB)-n))
     
-    o.start<-if(any(monotone!=0 | concave!=0)) rq.fit.sfnc(XB, y, tau=start.tau, R=R.monot, r=r.monot)
-      else rq.fit.sfn(XB, y=y, tau=start.tau) 
+    #browser()
+    
+    # o.start<-if(any(monotone!=0 | concave!=0)) rq.fit.sfnc(XB, y, tau=start.tau, R=R.monot, r=r.monot)
+    #   else rq.fit.sfn(XB, y=y, tau=start.tau) 
+    
+    o.start <- rqFit(XB, y, tau=start.tau, R=R.monot, r=r.monot)
+    
     if(is.null(o.start$fitted.values)) o.start$fitted.values<- y - o.start$residuals
     #browser()
     #Attenzione.. guarda gli oggetti che restituisce e che deve usare edf.rqXB(). Altrimenti non va..
@@ -562,8 +570,8 @@ ncross.rq.fitXBsparse <-
             if(lambda.ridge>0) XB<-rbind(XB, lambda.ridge*diag(ncol(XB))) #a small ridge penalty
           }
           
-          o<-rq.fit.sfnc(x=XB, y=y, tau=pos.taus[i], R=RR, r=rr)
-          
+          #o<-rq.fit.sfnc(x=XB, y=y, tau=pos.taus[i], R=RR, r=rr)
+          o<- rqFit(XB, y, tau=pos.taus[i], R=RR, r=rr)
           #browser()
           
           #o<-rq.fit.fnc(x=XB, y=y, tau=pos.taus[i], method="fnc", R=RR, r=rr, eps=myeps)
@@ -705,7 +713,8 @@ ncross.rq.fitXBsparse <-
             if(any(lambda>0)) XB<-rbind(B, D.matrix.lambda)
             if(lambda.ridge>0) XB<-rbind(XB, lambda.ridge*diag(ncol(XB))) #a small ridge penalty
           }
-          o<-rq.fit.sfnc(x=XB, y=y, tau=neg.taus[i], R=RR,r=rr)
+          o<- rqFit(XB, y, tau=neg.taus[i], R=RR, r=rr)
+          #o<-rq.fit.sfnc(x=XB, y=y, tau=neg.taus[i], R=RR,r=rr)
           #o<-rq.fit.fnc(x=XB,y=y,tau=neg.taus[i], R=RR, r=rr, eps=myeps)
           ##########==============================================================
           
